// Copyright 2018 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "jwt_verify_lib/check_audience.h"
#include "gtest/gtest.h"

namespace google {
namespace jwt_verify {
namespace {

TEST(CheckAudienceTest, TestConfigNotPrefixNotTailing) {
  CheckAudience checker({"example_service"});
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service/"}));
}

TEST(CheckAudienceTest, TestConfigHttpPrefixNotTailing) {
  CheckAudience checker({"http://example_service"});
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service/"}));
}

TEST(CheckAudienceTest, TestConfigHttpsPrefixNotTailing) {
  CheckAudience checker({"https://example_service"});
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service/"}));
}

TEST(CheckAudienceTest, TestConfigNotPrefixWithTailing) {
  CheckAudience checker({"example_service/"});
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service/"}));
}

TEST(CheckAudienceTest, TestConfigHttpPrefixWithTailing) {
  CheckAudience checker({"http://example_service/"});
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service/"}));
}

TEST(CheckAudienceTest, TestConfigHttpsPrefixWithTailing) {
  CheckAudience checker({"https://example_service/"});
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"https://example_service"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"example_service/"}));
  EXPECT_TRUE(checker.areAudiencesAllowed({"http://example_service/"}));
}

}  // namespace
}  // namespace jwt_verify
}  // namespace google
